# *DIRESA-Torch*


### Overview

*DIRESA-Torch* is a Python package for dimension reduction based on 
[PyTorch](https://pytorch.org). The distance-regularized 
Siamese twin autoencoder architecture is designed to preserve distance 
(ordering) in latent space while capturing the non-linearities in
the datasets.


### Install *DIRESA-Torch*

Install *DIRESA-Torch* with the following command:

``` bash
  pip install diresa-torch
```

### Documentation

The *DIRESA* documentation can be found on [Read the Docs](https://diresa-torch.readthedocs.io)